summaryrefslogtreecommitdiff
path: root/backend/dl.cc
diff options
context:
space:
mode:
Diffstat (limited to 'backend/dl.cc')
-rw-r--r--backend/dl.cc12
1 files changed, 6 insertions, 6 deletions
diff --git a/backend/dl.cc b/backend/dl.cc
index 06698c9..305b4e0 100644
--- a/backend/dl.cc
+++ b/backend/dl.cc
@@ -8,10 +8,10 @@
#include "dl.h"
#include "utils.h"
-namespace slack {
-
+namespace katja
+{
/**
- * slack::Dl::collect_cache_info:
+ * katja::Dl::collect_cache_info:
* @tmpl: temporary directory for downloading the files.
*
* Download files needed to get the information like the list of packages
@@ -59,7 +59,7 @@ Dl::collect_cache_info (const char *tmpl) noexcept
}
/**
- * slack::Dl::generate_cache:
+ * katja::Dl::generate_cache:
* @job_data: A #JobData.
* @tmpl: temporary directory for downloading the files.
*
@@ -253,7 +253,7 @@ Dl::~Dl () noexcept
}
/**
- * slack::Dl::Dl:
+ * katja::Dl::Dl:
* @name: Repository name.
* @mirror: Repository mirror.
* @order: Repository order.
@@ -262,7 +262,7 @@ Dl::~Dl () noexcept
*
* Constructor.
*
* Return value: New #slack::Dl.
**/
Dl::Dl (const char *name, const char *mirror,
std::uint8_t order, const char *blacklist, char *index_file) noexcept
@@ -262,7 +262,7 @@ Dl::~Dl () noexcept
* Constructor.
*
- * Return value: New #slack::Dl.
+ * Return value: New #katja::Dl.
**/
Dl::Dl (const char *name, const char *mirror,